Archive browsing
================

.. image:: ../../tests/robotframework/screenshots/browsable_home.png
   :class: sosse-screenshot
   :scale: 50%

The :ref:`browsable home option <conf_option_browsable_home>` can be enabled to display the list of archived websites on the homepage. When enabled, all entry points URL crawled are displayed (see :doc:`crawl/add_to_queue`) are shown. Displayed website can be customized using the :ref:`show on homepage <document_show_on_homepage>` option of documents.
